#
# spec file for package keybase-client
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2021 Matthias Bach <marix@marix.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           keybase-client
Version:        6.0.2
Release:        1.3
Summary:        Keybase command line client
License:        BSD-3-Clause
Group:          Productivity/Security
URL:            https://github.com/keybase/client/
Source:         client-%{version}.tar.xz
Source1:        README.SUSE
Source2:        keybase.service
Source3:        vendor-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  go1.16
BuildRequires:  golang-packaging
BuildRequires:  gzip
BuildRequires:  pkgconfig
BuildRequires:  tar
BuildRequires:  xz
BuildRequires:  pkgconfig(systemd)
%{go_nostrip}
%{?systemd_ordering}
%{go_provides}

%description
The Keybase command line client allows to manage a keybase.io account from
the command line. It includes functionality for encryption, signing, and
signature verifcation. It can create proofs to link a PGP key to other
accounts like Twitter, Github, or a Homepage. In addition, it allows to look
up keys for such accounts that people have created a proof for.

%prep
%setup -q -n client-%{version}
tar -xaf %{SOURCE3}

%build
%{goprep} github.com/keybase/client/go
%{gobuild} -tags production keybase

%install
%{goinstall}
%{gofilelist}
install -D -m 644 -p %{SOURCE2} %{buildroot}%{_userunitdir}/keybase.service
install -D -m 644 -p %{SOURCE1} %{buildroot}/%{_docdir}/%{name}/README.SUSE
%fdupes %{buildroot}/%{_prefix}

%check
%{gotest} github.com/keybase/client/go/keybase

%post
%systemd_user_post keybase.service

%preun
%systemd_user_preun keybase.service

%files -f file.lst
%{_bindir}/keybase
%{_userunitdir}/keybase.service
%{_docdir}/%{name}
%{_docdir}/%{name}/README.SUSE
%license LICENSE

%changelog
* Sun Jun 26 2022 Matthias Bach <marix@marix.org> - 6.0.2
- Upgrade to version 6.0.2
  * Bug fixes
* Sat Jan 22 2022 Matthias Bach <marix@marix.org> - 5.9.1
- Upgrade to version 5.9.1
  * Fix issue where the KBFS mountpoint would be disconnected after
    restarting Keybase (Transport endpoint is not connected).
* Thu Dec 30 2021 Matthias Bach <marix@marix.org> - 5.9.0
- Upgrade to version 5.9.0
  * Security enhancements
- Upgrade Go version used for compilation to 1.16
- Added vendor-5.9.0.tar.xz providing vendored dependencies, as
  upstream no longer vendors them.
* Sat Oct  2 2021 Matthias Bach <marix@marix.org> - 5.8.1
- Upgrade to version 5.8.1
  * Security enhancements
* Thu Jun 24 2021 Matthias Bach <marix@marix.org>
- Upgrade to version 5.7.1
  * Security enhancements
* Sun Feb  7 2021 Matthias Bach <marix@marix.org> - 5.6.1
- Upgrade to version 5.6.1
  * Various bug fixes, security enhancements
* Thu Dec 24 2020 Matthias Bach <marix@marix.org>
- Make package conform to spec-cleaner
* Sat Oct 17 2020 Matthias Bach <marix@marix.org>
- Upgrade to version 5.5.2
  * Miscellaneous bugfixes
* Sun Jun  7 2020 Matthias Bach <marix@marix.org>
- Upgrade to version 5.5.1
  * Improved file sharing with email addresses
  * Fix a panic when KEYBASE_DISABLE_FAVORITES is set. This should
    not affect typical use cases.
* Fri May 15 2020 Matthias Bach <marix@marix.org>
- Upgrade to version 5.4.1
  * You can now search for open teams using chat search.
  * KBFS performance fixed.
  * Many performance improvements and bug fixes.
- Explicity use go1.14 as the client won't build with older
  versions.
* Mon Feb  3 2020 Matthias Bach <marix@marix.org>
- Upgrade to version 5.2.0
  * Bots: you can now install bots into your conversations. Kick
    off a meeting with Google Meet Bot, watch for commits with
    GitHub Bot, create new issues in JIRA, and more, all without
    leaving Keybase.
- Limit source file to the `go` subdirectory of the repository as
  we only build the command line client and the GUI sources contain
  files with problematic licenses.
* Fri Dec 27 2019 Stefan Weiberg <sweiberg@suse.com>
- Upgrade to version 5.1.1
  * Enabled blocking users from their profile
- Upgrade to version 5.1.0
  * New features for blocking and reporting bad people
  * Large File Storage in git
  * Various bug fixes around team management
  * Dark mode fixes
  * Smaller bug fixes and performance improvements
- Upgrade to version 5.0.0
  * Switch between multiple accounts quickly
  * Send short audio snippets in chat in mobile
  * Sync KBFS files to your device for offline access
  * Keybase FM: Learn about new features in each release in the app
  * Better location sharing in chat
  * Removed navigation while in chat in mobile
  * Dark mode fixes
  * Faster startup time
  * Improved animations
* Tue Oct 29 2019 Matthias Bach <marix@marix.org>
- Upgrade to version 4.7.2
  * Fix an issue with device provisioning.
  * Fix account deletion.
  * Better account-reset workflow.
  * Faster inbox loading.
* Sun Oct 13 2019 Matthias Bach <marix@marix.org>
- Upgrade to version 4.6.0
  * Added bot managment commands.
  * Better support for federated addresses in Stellar feature.
  * Miscellaneous bug fixes.
* Sat Aug 17 2019 Matthias Bach <marix@marix.org>
- Upgrade to version 4.3.1
  * Replies will automatically notify who you're replying to.
  * Support user lookup by phone number.
* Wed Jul 24 2019 Matthias Bach <marix@marix.org>
- Upgrade to version 4.2.1
  * Search across all chat conversations.
  * Team mentions in chat.
* Thu Jun  6 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  make the build dep chain cheaper by using systemd-mini.
* Fri Apr 12 2019 Matthias Bach <marix@marix.org>
- Upgrade to version 3.2.2
  * Support for Mastodon social proofs.
  * New slash commands.
  * Set short term retention policies on teams and direct messages.
- This version requires Go >= 1.10 and will thus no longer work on
  Leap 15.0.
* Wed Jan  2 2019 marix@marix.org
- Upgrade to version 2.11.0
  * Improvements to filesystem and message handling.
* Fri Nov 23 2018 marix@marix.org
- Upgrade to version 2.10.1
* Tue Nov  6 2018 marix@marix.org
- Add a README.SUSE highlighting differences in usage to what is
  documented by upstream.
- Drop the upstream README that only contains information relevant
  for people building from source.
* Fri Nov  2 2018 marix@marix.org
- Add the required Keybase service.
* Fri Nov  2 2018 marix@marix.org
- Use the production site instead of building a development client.
* Thu Nov  1 2018 marix@marix.org
- Stop installing development files.
* Thu Nov  1 2018 marix@marix.org
- Initial package version
